# 準備

## SIP の認証情報を JSON で返すプログラムやファイルをサーバー上に用意する

### JSON の形式

  ```json
  {
    "username": "*作成したWebRTCの内線アカウント11桁番号*",
    "password": "*作成したWebRTCの内線アカウントのパスワード*"
  }
  ```

### サンプル (tmp/GetCredentials.json)

  ```json
  {
    "username": "XXXXXXXXXXX",
    "password": "YYYYYYYYYYY"
  }
  ```

  * サンプルでは単純な静的なファイルになっておりますが、認証情報 (ID/パスワード) を扱うため、環境に応じてセキュリティ対策を行なったものをご用意ください。


# 実装

## SIP の発信処理を JavaScript で記述する

SIP での発信までには、大まかに分けて以下の 4 つのステップで実行します。

1. 必要な JavaScript ライブラリを読み込む

  ```HTML
  <script src="https://cdn.temasys.io/adapterjs/0.15.x/adapter.debug.js"></script>
  <script src="js/SIPml-api.js"></script>
  <script src="js/webrtc.js"></script>
  <script src="js/simpleCall.js"></script>
  ```

  * ご提供する js フォルダと sounds フォルダは、必ず設置するサーバー上にそのままコピー・配置してください。

2. SIP の初期化

  ```JavaScript
  const call = new SimpleCall();
  ```

3. SIP の認証情報を設定する

  ```JavaScript
  call.getCredential('認証情報を取得するURL');
  ```

  * getCredential() 関数の引数には、URLの文字列、もしくは Request オブジェクトを渡してください。

4. 発信処理

  ```JavaScript
  call.execute('発信番号設定', {
    onStart: 発信開始時のコールバックを設定,
    onStop: 通話終了時のコールバックを設定,
  })
  ```

### 発信番号の形式

  ```
  *3XXXXXXXXXXXX_12YYYYYYYYYYY
  ```

* 設定する番号は  **3+[外線グループID]+_12+[発信先内線番号]**
  * 外線グループID (XXXXXXXXXXXX の部分) は **代表内線番号から8を除いたもの**
  * アンダーバーより **左側** はどの外線番号から発信したいかという **発信元の設定**
  * アンダーバーより **右側** はどのアプリIDを鳴らしたいかという **発信先の設定**
